Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(195)

Unified Diff: sdk/lib/isolate/isolate.dart

Issue 1401713002: Rename [packages] to [packageMap] as Isolate.spawnUri parameter. (Closed) Base URL: https://github.com/dart-lang/sdk.git@master
Patch Set: Fix typo Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sdk/lib/_internal/js_runtime/lib/isolate_patch.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/isolate/isolate.dart
diff --git a/sdk/lib/isolate/isolate.dart b/sdk/lib/isolate/isolate.dart
index d6b4c0b5b41e50ff1b0005640f2b9f614965559f..324c1e3b5b0a379fc19563565b18d6b06ac7581b 100644
--- a/sdk/lib/isolate/isolate.dart
+++ b/sdk/lib/isolate/isolate.dart
@@ -235,7 +235,7 @@ class Isolate {
*
* WARNING: The [checked] parameter is not implemented on all platforms yet.
*
* If either the [packageRoot] or the [packages] parameter is provided,
* it is used to find the location of package sources in the spawned isolate.
*
* The `packageRoot` URI must be a "file" or "http"/"https" URI that specifies
@@ -245,7 +245,7 @@ class Isolate {
* resolved against this location, as by
* `packageRoot.resolve("foo/bar.dart")`.
*
* The `packages` map maps package names to URIs with the same requirements
* as `packageRoot`. Package imports (like `"package:foo/bar/baz.dart"`) in
* the new isolate are resolved against the URI for that package (if any),
* as by `packages["foo"].resolve("bar/baz.dart")
@@ -253,11 +253,11 @@ class Isolate {
* This resolution also applies to the main entry [uri]
* if that happens to be a package-URI.
*
* If both [packageRoot] and [packages] are omitted, the new isolate uses
* the same package resolution as the current isolate.
* It's not allowed to provide both a `packageRoot` and a `package` parameter.
*
* WARNING: The [packageRoot] and [packages] parameters are not implemented
* on all platforms yet.
*
* The [environment] is a mapping from strings to strings which the
@@ -283,7 +283,7 @@ class Isolate {
bool checked,
Map<String, String> environment,
Uri packageRoot,
- Map<String, Uri> packages});
+ Map<String, Uri> packageMap});
/**
* Requests the isolate to pause.
« no previous file with comments | « sdk/lib/_internal/js_runtime/lib/isolate_patch.dart ('k') | no next file » | no next file with comments »
@@ -235,7 +235,7 @@ class Isolate {
* WARNING: The [checked] parameter is not implemented on all platforms yet.
*
- * If either the [packageRoot] or the [packages] parameter is provided,
+ * If either the [packageRoot] or the [packageMap] parameter is provided,
* it is used to find the location of package sources in the spawned isolate.
*
@@ -245,7 +245,7 @@ class Isolate {
* `packageRoot.resolve("foo/bar.dart")`.
*
- * The `packages` map maps package names to URIs with the same requirements
+ * The `packageMap` map maps package names to URIs with the same requirements
* as `packageRoot`. Package imports (like `"package:foo/bar/baz.dart"`) in
* the new isolate are resolved against the URI for that package (if any),
@@ -253,11 +253,11 @@ class Isolate {
* if that happens to be a package-URI.
*
- * If both [packageRoot] and [packages] are omitted, the new isolate uses
+ * If both [packageRoot] and [packageMap] are omitted, the new isolate uses
* the same package resolution as the current isolate.
* It's not allowed to provide both a `packageRoot` and a `package` parameter.
@@ -253,11 +253,11 @@ class Isolate {
* It's not allowed to provide both a `packageRoot` and a `package` parameter.
*
- * WARNING: The [packageRoot] and [packages] parameters are not implemented
+ * WARNING: The [packageRoot] and [packageMap] parameters are not implemented
* on all platforms yet.
*

Powered by Google App Engine
This is Rietveld 408576698